@@ -118,7 +118,7 @@ GenoConvert <- function(InData = NULL,
                         InFormat = "raw",
                         OutFile = NA,
                         OutFormat = "seq",
-                        Missing = c("-9", "??", "?", "NA", "NULL",
+                        Missing = c("-9", "??", "?", "NA", "NULL","-1",
                                     c("0")[InFormat %in% c("col","ped")]),
                         sep = c(" ", "\t", ",", ";"),
                         header = NA,
